import fs from "fs";
import express from "express";
import axios from "axios";
import { Blob } from "buffer";

// const app = express();

// app.get("/", async function (req, res) {

// });

// app.listen(8000, function () {
//   console.log("Listening on port 8000!");
// });

class UrlPool {

	urls: string[];
	used: boolean[] = [];

	constructor(urls: string[]) {
		this.urls = urls;
		for(let i=0; i<urls.length; i++) {
			this.used[i] = false;
		}
	}

	get(): [number, string] | undefined {
		for(let i=0; i<this.urls.length; i++) {
			if(this.used[i]) continue;
			this.used[i] = true;
			return [i, this.urls[i]];
		}
	}

	return(i: number) {
		this.used[i] = false;
	}

	available(count?: number) {
		let available: number[] = [];
		for(let i=0; i<this.used.length; i++) {
			if(!this.used[i]) {
				available.push(i);
			}
		}
		return count ? available.slice(0, count) : available;
	}

}

class Downloader {

	pool: UrlPool;
	chunks: Buffer[] = [];
	downloaded_chunks = 0;
	total_chunks = 0;

	chunk_size = 1000000;
	total_size = 0;

	constructor(pool: UrlPool) {
		this.pool = pool;
	}

	async init() {
		let url = this.pool.get();
		if(!url) return false;
		let r = await axios.get(url[1], {
			responseType: 'arraybuffer',
			headers: {
				Range: `bytes=0-0`
			}
		});
		this.total_size = parseInt(r.headers["content-range"].split("/")[1]);
		this.pool.return(url[0]);
	}

	async download_chunk(i: number) {

		let from = i*this.chunk_size;
		let to = (from+this.chunk_size-1);
		if(to > this.total_size) to = this.total_size;

		if(this.chunks[i] || from > this.total_size) return false;
		this.total_chunks++;

		let url = this.pool.get();
		if(!url) return false;

		let r = await axios.get(url[1], {
			responseType: 'arraybuffer',
			headers: {
				Range: `bytes=${from}-${to}`
			}
		});

		this.chunks[i] = r.data;
		this.pool.return(url[0]);
		this.downloaded_chunks++;
		return true;

	}

}

let pool = new UrlPool(`https://download.uloz.to/Ps;Hs;up=0;cid=1902599176;uip=94.140.115.76;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=182198590;tm=1645794132;ut=f;rs=0;He;ch=eb2339ff694fef5eb6c339dd143d0323;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=1902599176&De
https://download.uloz.to/Ps;Hs;up=0;cid=217796726;uip=5.2.69.50;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=1611819014;tm=1645794134;ut=f;rs=0;He;ch=ca357e24ac0a37f64736f1374a147de5;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=217796726&De
https://download.uloz.to/Ps;Hs;up=0;cid=1450029767;uip=95.214.54.97;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=1561658429;tm=1645794137;ut=f;rs=0;He;ch=24be9dd917c49b04df7de7b71dabce04;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=1450029767&De
https://download.uloz.to/Ps;Hs;up=0;cid=999887453;uip=185.220.100.247;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=1107334260;tm=1645794138;ut=f;rs=0;He;ch=85965c058db44eb9dac39f9552aaf31c;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=999887453&De
https://download.uloz.to/Ps;Hs;up=0;cid=247903693;uip=217.79.178.53;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=2013848098;tm=1645794139;ut=f;rs=0;He;ch=f129cc7c49aef5f6901a301ffb09e78f;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=247903693&De
https://download.uloz.to/Ps;Hs;up=0;cid=2132096430;uip=185.220.101.11;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=673797847;tm=1645794140;ut=f;rs=0;He;ch=5091a5e579ace8a497d6f0adcf497b0c;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=2132096430&De
https://download.uloz.to/Ps;Hs;up=0;cid=169365638;uip=185.220.100.242;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=1924737005;tm=1645794141;ut=f;rs=0;He;ch=ece065aed937f898d9adb862f9100a8f;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=169365638&De
https://download.uloz.to/Ps;Hs;up=0;cid=686552167;uip=45.153.160.140;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=655990281;tm=1645794142;ut=f;rs=0;He;ch=c770368d9c5536e7f2b53ee470486d41;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=686552167&De
https://download.uloz.to/Ps;Hs;up=0;cid=2001187746;uip=209.141.50.178;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=668227825;tm=1645794144;ut=f;rs=0;He;ch=140d095b032c6f35294f29b3d203f9f2;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=2001187746&De
https://download.uloz.to/Ps;Hs;up=0;cid=1595393867;uip=89.58.19.0;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=1798363942;tm=1645794145;ut=f;rs=0;He;ch=592768bff1847a894fd4847d599fc071;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=1595393867&De
https://download.uloz.to/Ps;Hs;up=0;cid=504210218;uip=109.70.100.30;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=802460485;tm=1645794147;ut=f;rs=0;He;ch=471cfbd448d9491e36971c33b69aac02;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=504210218&De
https://download.uloz.to/Ps;Hs;up=0;cid=459126116;uip=185.220.101.191;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=612989177;tm=1645794148;ut=f;rs=0;He;ch=8d85af0103145df2f39468beaf1dd107;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=459126116&De
https://download.uloz.to/Ps;Hs;up=0;cid=407791723;uip=185.107.70.56;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=980716832;tm=1645794149;ut=f;rs=0;He;ch=00bb0669902cfcfac53b2e2d5d86f10c;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=407791723&De
https://download.uloz.to/Ps;Hs;up=0;cid=354646677;uip=185.14.97.145;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=652261345;tm=1645794150;ut=f;rs=0;He;ch=bb570af93d599f7efd4001f254c99dd8;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=354646677&De
https://download.uloz.to/Ps;Hs;up=0;cid=1203492247;uip=185.220.100.242;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=1443730432;tm=1645794150;ut=f;rs=0;He;ch=154be66e84eaed3b70c5e4a86a1483f4;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=1203492247&De
https://download.uloz.to/Ps;Hs;up=0;cid=1834962753;uip=51.15.80.14;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=1359278523;tm=1645794152;ut=f;rs=0;He;ch=d5e04fc39559e225a73e282b2773ce01;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=1834962753&De
https://download.uloz.to/Ps;Hs;up=0;cid=1410071005;uip=51.195.107.236;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=98246841;tm=1645794153;ut=f;rs=0;He;ch=2c6975a4bf8f9748dbcd4cfdbab6f8f3;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=1410071005&De
https://download.uloz.to/Ps;Hs;up=0;cid=618501362;uip=89.163.252.230;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=482942366;tm=1645794154;ut=f;rs=0;He;ch=d71fa4e86418ae0f367320c25ccf7fff;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=618501362&De
https://download.uloz.to/Ps;Hs;up=0;cid=16241564;uip=185.220.101.80;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=1830519811;tm=1645794156;ut=f;rs=0;He;ch=9b7f8b01036203b40de882f086fc3c96;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=16241564&De
https://download.uloz.to/Ps;Hs;up=0;cid=199533540;uip=5.2.69.50;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=241392663;tm=1645794157;ut=f;rs=0;He;ch=08bc8c39cd140e8223ac3bf90efd0917;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=199533540&De
https://download.uloz.to/Ps;Hs;up=0;cid=338699318;uip=185.220.101.36;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=665274515;tm=1645794169;ut=f;rs=0;He;ch=0ac0a93a016af79bcf096ad670bd53ce;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=338699318&De
https://download.uloz.to/Ps;Hs;up=0;cid=2069360319;uip=185.220.101.70;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=1458440381;tm=1645794170;ut=f;rs=0;He;ch=cfeb317b55823cc493255691d8e2d026;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=2069360319&De
https://download.uloz.to/Ps;Hs;up=0;cid=737036779;uip=185.220.100.241;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=602733030;tm=1645794171;ut=f;rs=0;He;ch=d5d16acaa5129b263a146b6ce43603ed;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=737036779&De
https://download.uloz.to/Ps;Hs;up=0;cid=1446127845;uip=185.100.86.74;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=1673222080;tm=1645794173;ut=f;rs=0;He;ch=401f40fce22ad467793aa5f007759d2f;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=1446127845&De
https://download.uloz.to/Ps;Hs;up=0;cid=1428749874;uip=109.70.100.35;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=370384322;tm=1645794184;ut=f;rs=0;He;ch=c9171f2bff8e58269bf236f444689d67;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=1428749874&De
https://download.uloz.to/Ps;Hs;up=0;cid=40819559;uip=205.185.120.206;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=807352493;tm=1645794186;ut=f;rs=0;He;ch=1d256c63a43d49173e5209451c1a8562;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=40819559&De
https://download.uloz.to/Ps;Hs;up=0;cid=72025195;uip=188.68.58.0;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=1585441715;tm=1645794187;ut=f;rs=0;He;ch=866e484ce49bf9582d8f5131f10e6a16;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=72025195&De
https://download.uloz.to/Ps;Hs;up=0;cid=1675098407;uip=45.153.160.131;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=2031743991;tm=1645794187;ut=f;rs=0;He;ch=1fe021d8f985ad7de4a0de56a26bb5c9;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=1675098407&De
https://download.uloz.to/Ps;Hs;up=0;cid=142983770;uip=185.220.101.78;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=141502631;tm=1645794192;ut=f;rs=0;He;ch=9a2704d47659b6d48088c79cd6717185;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=142983770&De
https://download.uloz.to/Ps;Hs;up=0;cid=1121470512;uip=185.220.101.187;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=425853631;tm=1645794194;ut=f;rs=0;He;ch=61bbdf08a75e4d406cab1346dab9fa8d;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=1121470512&De
https://download.uloz.to/Ps;Hs;up=0;cid=367272634;uip=185.129.61.3;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=898723366;tm=1645794196;ut=f;rs=0;He;ch=83183e119aa6a766ba91c5ccb86738f3;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=367272634&De
https://download.uloz.to/Ps;Hs;up=0;cid=460337998;uip=185.195.71.2;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=647853543;tm=1645794197;ut=f;rs=0;He;ch=51e3d03d39878f1fb001d9db5eda69b5;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=460337998&De
https://download.uloz.to/Ps;Hs;up=0;cid=1168395994;uip=199.249.230.116;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=1588708485;tm=1645794200;ut=f;rs=0;He;ch=773e6f922f8d10f07b84140c0d6d5e2c;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=1168395994&De
https://download.uloz.to/Ps;Hs;up=0;cid=381575571;uip=107.189.30.58;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=1859251700;tm=1645794201;ut=f;rs=0;He;ch=c6eb1cabb8ce08bdf856d58157d1c2df;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=381575571&De
https://download.uloz.to/Ps;Hs;up=0;cid=662179198;uip=104.244.77.122;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=1387674204;tm=1645794213;ut=f;rs=0;He;ch=28a11d021970d8aeb62a4c3cf79c47fe;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=662179198&De
https://download.uloz.to/Ps;Hs;up=0;cid=38785771;uip=185.220.100.245;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=1531857518;tm=1645794214;ut=f;rs=0;He;ch=dcccba84d422d7e4f48965e4f190a956;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=38785771&De
https://download.uloz.to/Ps;Hs;up=0;cid=1467953227;uip=109.70.100.77;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=703474084;tm=1645794215;ut=f;rs=0;He;ch=8db82b3ed8e22e5f02a783899524025e;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=1467953227&De
https://download.uloz.to/Ps;Hs;up=0;cid=1872929816;uip=89.58.30.164;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=2032740704;tm=1645794227;ut=f;rs=0;He;ch=45bd81085d80fee23cf3e04161ac2d91;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=1872929816&De
https://download.uloz.to/Ps;Hs;up=0;cid=690400065;uip=185.220.100.246;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=86134805;tm=1645794228;ut=f;rs=0;He;ch=fdbf14ca226181f6f5ded2c2c9a07f5f;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=690400065&De
https://download.uloz.to/Ps;Hs;up=0;cid=784026385;uip=51.158.183.63;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=835601412;tm=1645794229;ut=f;rs=0;He;ch=3dcb6d2130ee2a0b3afa102f8addd628;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=784026385&De
https://download.uloz.to/Ps;Hs;up=0;cid=294526816;uip=185.220.100.240;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=694601773;tm=1645794240;ut=f;rs=0;He;ch=d3d1002adde23b7c2c09ae9740353bc9;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=294526816&De
https://download.uloz.to/Ps;Hs;up=0;cid=509923097;uip=81.17.18.60;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=1103178990;tm=1645794242;ut=f;rs=0;He;ch=61e12562da753b11ac270dec1631e67b;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=509923097&De
https://download.uloz.to/Ps;Hs;up=0;cid=528529418;uip=107.189.1.160;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=1141316485;tm=1645794249;ut=f;rs=0;He;ch=fe6b3c31b4c1f76cc5422ee4a8947012;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=528529418&De
https://download.uloz.to/Ps;Hs;up=0;cid=1671744639;uip=109.70.100.75;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=138941775;tm=1645794250;ut=f;rs=0;He;ch=f90c71da63bb9399b4b560b556e1da92;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=1671744639&De
https://download.uloz.to/Ps;Hs;up=0;cid=1721437237;uip=45.153.160.132;aff=uloz.to;did=uloz-to;fide=t4C8X2C;fs=eRGCx2K8vFiX;hid=zCM7r63;rid=303699948;tm=1645794253;ut=f;rs=0;He;ch=0711594c0eff1490b091c2b95a62bcd2;Pe/file/eRGCx2K8vFiX/frozen-2013-1080p-bluray-cz-titulky-mkv?bD&c=1721437237&De`.split("\n"));


(async () => {

	let downloader = new Downloader(pool);

	await downloader.init();
	console.log(downloader.total_size);

	let limit = Math.ceil(downloader.total_size/downloader.chunk_size);
	let chunk = -1;

	let interval = setInterval(() => {
		let available = pool.available(limit-chunk);
		if(available.length) {
			console.log("downloading new chunks", available.length);
			available.forEach(async (i: number) => {
				chunk++;
				if(!await downloader.download_chunk(chunk)) console.warn("Error!");
			});
		}
		console.log(downloader.downloaded_chunks + " / " + downloader.total_chunks);
		if(downloader.total_chunks == downloader.downloaded_chunks) {
			clearInterval(interval);
			console.log(downloader.chunks.length);
			fs.writeFileSync("vid.mkv", Buffer.concat(downloader.chunks));
		}
	}, 1000);

})();